==> apollo-mocknetworkinterface-1.0.0.tgz: package/README.md <==
[apollo-mocknetworkinterface](https://github.com/siteone/apollo-mocknetworkinterface)
===================================
[![npm version](https://img.shields.io/npm/v/apollo-mocknetworkinterface.svg?style=flat-square)](https://www.npmjs.com/package/apollo-mocknetworkinterface)

Installation
------------
To install the stable version:

<code>
npm install --save apollo-mocknetworkinterface
</code>

What is the purpose of the package?
------------

There are couple of approaches how to test React Components connected to ```react-apollo```.
I have read great articles like:
- https://medium.com/@ferdingler/testing-apollo-react-components-a7618d8a9e7a
- and few more...
But all examples I've found are using ```mockNetworkInterface``` from 'apollo-test-utils' or 'react-apollo/test-utils' packages.
This interface is a bit dummy and only thing that allows is returning responses from array. For example you can set 4 mocked responses, they will be returned in exact order and then is over (no more responses will be returned).
I wasn't only one, who was struggling on that:
- https://github.com/apollographql/apollo-client/issues/535
- https://github.com/apollographql/react-apollo/issues/1144
Unfortunatelly Apollo doesn't offer much better interface.

To make things better, I've created this library, and so you can return programatically mocked any response. See example below. Note that you can use anything

Example
------------
```javascript
import React from 'react';
import { ApolloClient, ApolloProvider, graphql } from 'react-apollo';
import renderer from 'react-test-renderer';
import MockNetworkInterface from '../src/index';
import query from './query.graphql';

const TestComponent = (props) => {
  if (props.data.loading) {
    return (<div>loading ... {JSON.stringify(props)}</div>);
  }
  return (<div>got data ... {JSON.stringify(props)}</div>);
};
const TestComponentWithApollo = graphql(query, {
  options: props => ({
    variables: { url: props.url },
  }),
})(TestComponent);

const createResponse = (request) => { // pure function returning data
  console.log('creating mocked response for request:', request); // eslint-disable-line no-console
  // will log: creating mocked response for request: { query: { kind: 'Document' ...
  return {
    data: {
      component: {
        id: 1,
        name: 'foo',
      },
    },
  };
};
const networkInterface = new MockNetworkInterface(createResponse, { timeout: 100 });
const client = new ApolloClient({ networkInterface, addTypename: false });

it('render without exploding', (done) => {
  const component = renderer.create((
    <ApolloProvider client={client}>
      <div>
        <TestComponentWithApollo />
      </div>
    </ApolloProvider>
  ));
})
```

==> apollo-mocknetworkinterface-2.0.0.tgz: package/README.md <==
[apollo-mocknetworkinterface](https://github.com/siteone/apollo-mocknetworkinterface)
===================================
[![npm version](https://img.shields.io/npm/v/apollo-mocknetworkinterface.svg?style=flat-square)](https://www.npmjs.com/package/apollo-mocknetworkinterface)

Supports both Apollo 1 & Apollo 2
- Apollo 1: https://github.com/siteone/apollo-mocknetworkinterface/tree/v1.0.0
- Apollo 2: https://github.com/siteone/apollo-mocknetworkinterface/tree/v2.0.0

Installation
------------
To install the stable version:

<code>
npm install --save apollo-mocknetworkinterface@^1.0
</code>

What is the purpose of the package?
------------

Please read https://medium.com/p/ef0bbd17e686

Example
------------
```javascript
import React from 'react';
import { ApolloClient, ApolloProvider, graphql } from 'react-apollo';
import renderer from 'react-test-renderer';
import MockNetworkInterface from 'apollo-mocknetworkinterface';
import query from './query.graphql';

const TestComponent = (props) => {
  if (props.data.loading) {
    return (<div>loading ... {JSON.stringify(props)}</div>);
  }
  return (<div>got data ... {JSON.stringify(props)}</div>);
};
const TestComponentWithApollo = graphql(query, {
  options: props => ({
    variables: { url: props.url },
  }),
})(TestComponent);

const createResponse = (request) => { // pure function returning data
  console.log('creating mocked response for request:', request); // eslint-disable-line no-console
  // will log: creating mocked response for request: { query: { kind: 'Document' ...
  return {
    data: {
      component: {
        id: 1,
        name: 'foo',
      },
    },
  };
};
const mockedNetworkFetch = createMockedNetworkFetch(createResponse, { timeout: 100 }); // you can simulate network latency
const client = new ApolloClient({
  link: createHttpLink({ uri: 'http://localhost:3000', fetch: mockedNetworkFetch }),
  cache: new InMemoryCache(),
});

it('should render without exploding', (done) => {
  const component = renderer.create((
    <ApolloProvider client={client}>
      <div>
        <TestComponentWithApollo />
      </div>
    </ApolloProvider>
  ));
})
```
